@@ -2,31 +2,20 @@
 Example of using the batch API
 """
 
-import os
-import sys
 import logging
-from typing import Tuple
-from kentik_api import KentikAPI, Criterion, Upsert, Deletion, BatchOperationPart
+
+from kentik_api import BatchOperationPart, Criterion, Deletion, KentikAPI, Upsert
+from kentik_api.utils import get_credentials
 
 logging.basicConfig(level=logging.INFO)
 
 
-def get_auth_email_token() -> Tuple[str, str]:
-    try:
-        email = os.environ["KTAPI_AUTH_EMAIL"]
-        token = os.environ["KTAPI_AUTH_TOKEN"]
-        return email, token
-    except KeyError:
-        print("You have to specify KTAPI_AUTH_EMAIL and KTAPI_AUTH_TOKEN first")
-        sys.exit(1)
-
-
 def run_crud() -> None:
     """
     Runs example API calls and prints responses
     """
 
-    email, token = get_auth_email_token()
+    email, token = get_credentials()
     client = KentikAPI(email, token)
 
     print("### BATCH ON FLOW TAGS")
