@@ -1,14 +1,13 @@
-import time
 import logging
+import time
+from dataclasses import dataclass
 from queue import Queue
 from threading import Thread
-from typing import Callable, Any
-from dataclasses import dataclass
+from typing import Any, Callable
 
 from kentik_api.public.errors import IntermittentError
 from kentik_api.throttling.cmd import Cmd
 
-
 SuccessFunc = Callable[[Any], None]  # input: successful cmd execution result, output: none
 AbortFunc = Callable[[Exception], None]  # input: exception thrown by cmd, output: none
 
